/*!
 * ps.plone.mls | http://propertyshelf.com
 */

.mls section {
  clear: both;
  margin-top: 1.5em; /* Equals default line-height of p elements. */
}

.development_details h2
{
  text-transform: uppercase;
  text-align: center;
  margin-bottom:10px;
}

/* Description text */
#content .development__overview .documentDescription{
  font-size:15px;
  font-style: italic;
  font-weight: 400;
  color:#9c9c9b;
  text-align: center;
  margin-bottom:35px;
}

.development__overview .lead_image{
  position:relative;
  float:left;

  margin:0 30px 0 0;
  max-width: 100%;
}

.development__overview .lead_image img{
  max-width:100%;
  height:auto;
}
.development__overview .lead_image .caption{
  position:absolute;
  left:0;
  top:13px;
  padding:14px 18px 12px;
  background-color: rgb(0, 0, 0);
  background-color:rgba(0, 0, 0, 0.75);
  border: 1px solid #999;
  border-left:0 none transparent;

  color: #fefefe;
  text-transform: uppercase;
  font-size:18px;
  font-weight: normal;

}

.overview__long_description{
  font-size:15px;
}

/* Property groups */
.development_details #group-listings{
  list-style: outside none none;
  margin:0;
  padding:0;

}
.development_details #group-listings li{
  display:inline;
  text-transform: uppercase;
}

.development_details #group-listings li a:link{
  display:inline-block;
  background-color: #ccc;
  color:#fefefe;
  padding:20px;
  font-size:18px;
  margin-right:35px;
  margin-bottom:15px;
}
.development_details #group-listings li a.current{
  background-color: #9c9c9b;
  color:#fefefe;
  border-radius:0;

  font-weight: 400;
}

.development_details .listing-summary .tileItem{
  width: 48%;
  margin:0 1%;
  float:left;
}
.development_details .listing-summary .tileItem .image_row{
  overflow: auto;
  background-color: #e5e4e4;
  color:#767676;
  margin-bottom:3px;
  font-size: 18px;
  text-align: center;
  vertical-align: middle;
  height: 121px;
  position: relative;

}
@media (max-width: 900px) {
  body .development_details .listing-summary .tileItem{
    width:96%;
  }
}
@media (max-width: 660px) {
  .development_details .listing-summary .tileItem .image_row{
    max-height: 101px;
  }
}
@media (max-width: 500px) {
  body .development_details .listing-summary .tileItem{
    width:98%;
  }

  .development_details .listing-summary .tileItem .image_row{
    font-size: 14px;
  }
  .development_details .listing-summary .tileItem .data_row,
  body .development_details .data_row .lot_size{
    font-size: 12px;
  }
  body .development_details .data_row .price{
    font-size: 15px;
    height:28px;
    padding-top: 14px;
  }
}

@media (max-width: 380px) {
  .development_details .listing-summary .tileItem .image_row{
    max-height: 81px;
  }
}

.development_details .image_row .tileHeadline{
  padding:3%;
}

.development_details .listing-summary .tileItem .image_row a,
.development_details .listing-summary .tileItem .image_row a:link,
.development_details .listing-summary .tileItem .image_row a:visited{
  color:#767676;
}

#content-core.development_details .listing-summary figure{
  width:30%;
  height:100%;
  margin-right:2%;
  overflow: hidden;
}

#content-core.development_details .listing-summary figure a{
  border:0 none transparent;
  padding:0;
  color:#767676;
}

#content-core.development_details .listing-summary figure img{
  width:auto;
  height:auto;
  max-height:150%;
  min-height: 100%;
  max-width: 150%;
  position:relative;
  right:25%;
  top:-10%;
}

#content-core .listing-summary a:link{
  border:0 none transparent;
  color:#767676;
}
.development_details .listing-summary .tileItem .data_row div{
  display: inline-block;
}
.development_details .listing-summary .tileItem .data_row{
  background-color: #9c9c9b;
  color:#fff;
  font-size: 15px;
  min-height: 34px;
  position: relative;
}

.development_details .data_row .price{
  height:1.4em;
  padding-top:0.7em;
  font-size:20px;
  background-color: #ccc;
  width:30%;
  text-align: center;
}
.development_details .data_row .lot_size{
  width:30%;
  text-align: center;
}
/* land listings never have bath or bed rooms */
.development_details .ll .data_row .lot_size{
  width: 69%;
}

.development_details .data_row .beds{
  width:15%;
  text-align: right;
  padding-right: 2%;
  background-image: url(++resource++ps.plone.mls/icons/bed_white.png);
  background-repeat: no-repeat;
  background-position: center center;
}
.development_details .data_row .baths{
  width:15%;
  text-align: right;
  padding-right: 2%;
  background-image: url(++resource++ps.plone.mls/icons/shower_white.png);
  background-repeat: no-repeat;
  background-position: center center;
}

@media (max-width: 480px) {
  .development_details .data_row .beds{
    background-position:5px;
  }
}

#content .development_details #group-listings li a.current:hover,
#content .development_details #group-listings li a.current:focus,
#content .development_details #group-listings li a.current:visited{
  background-color: #9c9c9b;
}

#content .development_details #group-listings li a:hover,
#content .development_details #group-listings li a:focus,
#content .development_details #group-listings li a:visited{
  color:#fefefe !important;
  background-color: #ccc;
  border-radius:0;
}

.development__projectmap{
  overflow:hidden;
  text-align:center;
}
@media (max-width: 900px) {
  .development__projectmap .projectmap{
    display:none;
  }
  .development__projectmap{
    text-align:center;
  }

}

.pdf_download{
  background-color:#ff0000;
  display: inline-block;
  text-transform: uppercase;

  margin-top:20px;
  padding:15px 80px 14px 20px;

  position:relative;
  overflow: visible;
}
.pdf_download a:link{
  color:#fff !important;
  font-size: 20px;
  border:0 none transparent !important;
  font-family: 'Arial Narrow', Arial, sans-serif !important;
}

.pdf_download .icon{
  position:absolute;
  top:-10px;
  right:20px;
}

.pdf_download .text{
  padding-right:20px;
  display:inline-block;
}
.development__video_embedding{
  text-align: center;
}
.development__video_embedding .video{
  height: 0;
  margin: 1em 0 2em;
  padding-bottom: 56.25%;
  position: relative;
}
.development__video_embedding iframe{
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
.detail .overview__logo {
  background-color: #FFF;
  border: 1px solid #CCC;
  border: 1px solid rgba(0, 0, 0, 0.2);
  float: left;
  margin-bottom: 1em;
  margin-right: 1em;
  max-width: 10em;
  padding: 4px;
}

.detail .overview__logo img {
    max-width: 100%;
  }

.detail .overview__table {
  float: left;
  margin-bottom: 1em;
  margin-right: 1em;
}

.development__overview .listings__link {
  float: right;
}

.area__picture{
  background-color: #FFF;
  float: left;
  margin-bottom: 0;
  margin-right: 30px;
  padding: 0;
  max-width: 100%;
}

.area__picture img{
  max-width: 100%;
}

#content .development_details picture a:link{
  border-bottom:0 none transparent;
}

.representative__avatar {
  float: left;
  margin-bottom:0;
  margin-right: 30px;
}
.representative__avatar img {
    max-width: 100%;
    width: 100%;
  }

.representative__name,
.representative__user_title{

  font-style: italic;
  font-weight: bold;
}
.representative__name{
  text-transform: uppercase;
}

.map__canvas {
  height: 340px;
  width: 100%;
}

/* Amenity icons  */
.development__amenities,
.development__distances{
  text-align: center;
}
.development__amenities .amenitiesicon{
  font-size:60px;
  margin:2px;
  color:#ccc;
  display:inline-block;
  background-size: contain;
  background-repeat: no-repeat;
}

/* Distance icons */
.distanceicon{
    vertical-align:top;
    text-align:center;
    padding:10px;

    display:inline-block;
}
.count_1 .distanceicon{
  width:95%;
}
.count_2 .distanceicon{
  width:45%;
}
.count_3 .distanceicon{
  width:28%;
}
.count_4 .distanceicon{
  width:20%;
}
.count_5 .distanceicon{
  width:15%;
}
.count_6 .distanceicon{
  width:28%;
}

.distanceicon .icon{
  font-size:100px;
  color:#ccc;
}

@media (max-width: 800px) {
  .distanceicon .icon{
    font-size:90px;
  }
}
@media (max-width: 700px) {

  .count_2 .distanceicon,.count_4 .distanceicon
  .distanceicon{
    width:45%;
  }
  .count_3 .distanceicon,
  .count_5 .distanceicon,
  .count_6 .distanceicon{
    width:26%;
  }
  .distanceicon .icon{
    font-size:70px;
  }
}
@media (max-width: 420px) {
  .distanceicon,
  .count_3 .distanceicon,
  .count_5 .distanceicon,
  .count_6 .distanceicon{
    width:90%;
    padding:10px 0;
  }
}
@media (max-width: 360px) {
  .representative__avatar{
    margin-right: 0;
    float:none;
  }
  .representative__name,
  .representative__name, .representative__user_title{
    text-align: center;
  }
}

/*  Phases */
.development__phases{
  overflow: auto;
}
#content .phases__table{
  border:1px solid #c1c1c1;
  text-align: center;
}
#content .phases__table thead{
  border-bottom:1px solid #c1c1c1;
}

#content .phases__table th{
  font-weight: 400;
  cursor: pointer;
  text-transform: uppercase;
  font-size: 15px;
}
#content .phases__table a:link,
#content .phases__table a:visited{
  color:inherit;
  font-weight: 100;
  cursor: pointer;
}
#content .phases__table,
#content .phases__table thead,
#content .phases__table tbody{
  min-width: 100%
}

.phases__table thead tr{
  background: #efefef;
  background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0JveD0iMCAwIDEgMSIgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSI+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJncmFkLXVjZ2ctZ2VuZXJhdGVkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeDE9IjAlIiB5MT0iMCUiIHgyPSIwJSIgeTI9IjEwMCUiPgogICAgPHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjQ3JSIgc3RvcC1jb2xvcj0iI2Y2ZjZmNiIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiNlZGVkZWQiIHN0b3Atb3BhY2l0eT0iMSIvPgogIDwvbGluZWFyR3JhZGllbnQ+CiAgPHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);
  background: -moz-linear-gradient(top,  #efefef 0%, #eaeaea 47%, #d6d6d6 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#efefef), color-stop(47%,#eaeaea), color-stop(100%,#d6d6d6));
  background: -webkit-linear-gradient(top,  #efefef 0%,#eaeaea 47%,#d6d6d6 100%);
  background: -o-linear-gradient(top,  #efefef 0%,#eaeaea 47%,#d6d6d6 100%);
  background: -ms-linear-gradient(top,  #efefef 0%,#eaeaea 47%,#d6d6d6 100%);
  background: linear-gradient(to bottom,  #efefef 0%,#eaeaea 47%,#d6d6d6 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#efefef', endColorstr='#d6d6d6',GradientType=0 );

}
.phases__table tbody tr,
#content .phases__table .odd{
  background: #efefef;
  background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0JveD0iMCAwIDEgMSIgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSI+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJncmFkLXVjZ2ctZ2VuZXJhdGVkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeDE9IjAlIiB5MT0iMCUiIHgyPSIwJSIgeTI9IjEwMCUiPgogICAgPHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjQ3JSIgc3RvcC1jb2xvcj0iI2Y2ZjZmNiIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiNlZGVkZWQiIHN0b3Atb3BhY2l0eT0iMSIvPgogIDwvbGluZWFyR3JhZGllbnQ+CiAgPHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);
  background: -moz-linear-gradient(top,  #efefef 0%, #eaeaea 47%, #e3e3e3 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#efefef), color-stop(47%,#eaeaea), color-stop(100%,#e3e3e3));
  background: -webkit-linear-gradient(top,  #efefef 0%,#eaeaea 47%,#e3e3e3 100%);
  background: -o-linear-gradient(top,  #efefef 0%,#eaeaea 47%,#e3e3e3 100%);
  background: -ms-linear-gradient(top,  #efefef 0%,#eaeaea 47%,#e3e3e3 100%);
  background: linear-gradient(to bottom,  #efefef 0%,#eaeaea 47%,#e3e3e3 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#efefef', endColorstr='#e3e3e3',GradientType=0 );

}
.phases__table tbody tr:hover,
.phases__table tbody tr:focus,
#content .phases__table .odd:hover,
#content .phases__table .odd:focus{
  background: #ccc;
}
#content .phases__table tbody tr:hover a,
#content .phases__table tbody tr:focus a,
#content .phases__table .odd:hover a,
#content .phases__table .odd:focus a,
#content .phases__table tbody tr:hover a:visited,
#content .phases__table tbody tr:focus a:visited,
#content .phases__table .odd:hover a:visited,
#content .phases__table .odd:focus a:visited,
#content .phases__table tbody tr:hover a:hover,
#content .phases__table tbody tr:focus a:focus,
#content .phases__table .odd:hover a:hover,
#content .phases__table .odd:focus a:focus{
  color:#fff !important;
}

#content .phases__table .odd td{
  background-color: transparent;
}
table.phases__table th,
table.phases__table td{
  background: none repeat scroll 0 0 transparent;
  border:0 none transparent;
  text-align: center;
}
.phases__table td{
  background-color: transparent;
  border:0 none transparent;
}
/* Development header: Banner  */
.development__header{
  position:relative;
  overflow:hidden;
}

.development__header .development__banner{
  min-width:100%;
  max-width: 100%;
  height:auto;
  min-height:0;
}

.development__header .development_logo{
  max-width:30%;
  position:absolute;
  top:10%;
  left:5%;
}
.development__header .development_logo img{
  max-width:100%;
}
.development__header .development_title{
  color:#fffcfc;
  font-size:30px;
  font-weight:400;
  line-height: 1em;
  margin:0;
}

.development__header .header_caption {
    border:0 none transparent;
    position: absolute;
    bottom:0;
    left:0;
    right:0;
    text-align: left;
    padding:15px;
    background-color: #222;
    /* IE 8 */
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=75)";
  /* IE 5-7 */
  filter: alpha(opacity=75);
  /* Netscape */
  -moz-opacity: 0.75;
  /* Safari 1.x */
  -khtml-opacity: 0.75;
  /* Good browsers */
  opacity: 0.75;
}

body .development__header .development_location{
    text-align: left;
}

@media (max-width: 900px){
  .development__header .header_caption {
    position:relative;
    /* IE 8 */
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    /* IE 5-7 */
    filter: alpha(opacity=100);
    /* Netscape */
    -moz-opacity: 1;
    /* Safari 1.x */
    -khtml-opacity: 1;
    /* Good browsers */
    opacity: 1;
  }
}
@media (max-width: 800px){
  .development__header .development_title{
    font-size:1.7em;
  }
}
@media (max-width: 700px){
  .overview__long_description .lead_image{
    width:100%;
  }
  .development__overview .lead_image img{
    width:100%;
  }
  .development__overview .lead_image .caption{
    right:0;
  }
  .area__picture{
    width:100%;
    margin-right:0;
  }
  .area__picture img{
    width:100%;
  }

}
@media (max-width: 500px){
  .development__header .development_title{
    font-size:1.5em;
  }
}
.development__header .development_headline{
  color:#fffcfc;
  font-size:24px;
  font-weight:normal;
  margin:0;
}
@media (max-width: 800px){
.development__header .development_headline{
    font-size:1.2em;
  }
}
@media (max-width: 500px){
.development__header .development_headline{
    font-size:1em;
  }
}

.development__header .development_location{
  color:#fffcfc;
  font-size:1em;
  font-weight:normal;
  margin:0;
  text-align: center;
}
@media (max-width: 800px){
  .development__header .development_location{
    font-size:0.9em;
  }
}
@media (max-width: 500px){
  .development__header .development_location{
    font-size:0.8em;
  }
}

/* Contact form */
.development__contact form{
  color:#000;
  font-size: 16px;
  /* font-family: 'Arial Narrow', Arial, sans-serif; */

  padding: 15px 44px 5px;
  position: relative;

  border:1px solid #c1c1c1;
  background-color:#ebebeb;

  -webkit-box-shadow: 0 0 10px 0 rgba(0,0,0,0.25);
  -moz-box-shadow: 0 0 10px 0 rgba(0,0,0,0.25);
  box-shadow: 0 0 10px 0 rgba(0,0,0,0.25);

  background: rgba(230,230,230);
  background: -moz-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(230,230,230,1)), color-stop(53%, rgba(246,246,246,1)), color-stop(100%, rgba(255,255,255,1)));
  background: -webkit-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: -o-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: -ms-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: linear-gradient(to bottom, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e6e6e6', endColorstr='#ffffff', GradientType=0 );

}

.development__contact form div.field.error{
  background-color: transparent;
  border: 0 none transparent;
  font-size: 100%;
  margin: 0;
  padding: 0;
}

.development__contact .fieldErrorBox .error{
  background-color: transparent;
  border:0 none transparent;
  display:inline-block;
  padding:0;
  font-size: 12px;
  margin:0;

}

.development__contact label{
  display:inline-block;
  font-weight:400;
}
.development__contact label span.horizontal:before,
.development__contact #formfield-form-widgets-phone label:after{
  content:":";
  display: inline;
}

.development__contact input[type="text"]{
  display:block;
  width:100%;
  height:24px;
  font-size:15px;
  background-color: #e9e8e8;
  border-width: 1px;
}

.development__contact .fieldErrorBox{
  display:inline-block;
}
.development__contact #form textarea{
  display:block;
  max-width:100%;
  background-color: #e9e8e8;
  border-width: 1px;
  height:154px;
}
.development__contact #formfield-form-widgets-message{
  width:45%;
  position: absolute;
  top:15px;
  right:44px;
}
.development__contact #formfield-form-widgets-name,
.development__contact #formfield-form-widgets-sender_from_address,
.development__contact #form-widgets-phone{
  width:45%;
}
@media (max-width: 600px){
  .development__contact #formfield-form-widgets-name,
  .development__contact #formfield-form-widgets-sender_from_address,
  .development__contact #form-widgets-phone{
      width:40%;
  }
}
@media handheld, screen and (max-device-width: 480px) {
  .development__contact input,
  .development__contact textarea{
    font-size: 100% !important;
  }
  .development__contact #formfield-form-widgets-name,
  .development__contact #formfield-form-widgets-sender_from_address,
  .development__contact #form-widgets-phone{
      width:35%;
  }
}

.development__contact div.formControls{
  margin:0;
  text-align: right;
}

.development__contact input[type="submit"]{
  color:#000;
  text-transform: uppercase;
  font-size:14px;
  height:26px;
  padding: 2px 25px;
  border:1px solid #c1c1c1;
}
.development__vcard{
  padding:19px 44px;
  border:1px solid #c1c1c1;
  background-color:#ebebeb;

  -webkit-box-shadow: 0 0 10px 0 rgba(0,0,0,0.25);
  -moz-box-shadow: 0 0 10px 0 rgba(0,0,0,0.25);
  box-shadow: 0 0 10px 0 rgba(0,0,0,0.25);

  background: rgba(230,230,230);
  background: -moz-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(230,230,230,1)), color-stop(53%, rgba(246,246,246,1)), color-stop(100%, rgba(255,255,255,1)));
  background: -webkit-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: -o-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: -ms-linear-gradient(top, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  background: linear-gradient(to bottom, rgba(230,230,230,1) 0%, rgba(246,246,246,1) 53%, rgba(255,255,255,1) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e6e6e6', endColorstr='#ffffff', GradientType=0 );
}
.development__vcard h3{
  text-transform: uppercase;
  font-style: italic;
  font-weight:bold;
  font-size:16px;
  color:#000;
}

/* Contact us Anchor link*/

.anchorlink{
  position: fixed;
  left:0;
  top:40%;
  font-size: 18px;
  padding:10px;

  background: none repeat scroll 0 0 #205081;
  transform: rotate(270deg);
  transform-origin: left top 0;

  z-index: 99;

}
.anchorlink a:link,
.anchorlink a,
.anchorlink a:visited,
.anchorlink a:hover
{
  color: #fff !important;
  text-decoration: none !important;
}

/* Plone mobile.css fixes */
@media handheld, screen and (max-device-width: 480px) {

  #portal-top {
    font-size: 100%;
  }

  input, textarea {
    font-size: inherit !important;
  }

}

.listingsearchbanner {
  background-position: 50% 50%;
  background-size: cover;
  margin-bottom: 1em;
  padding: 8em;
}

.listingsearchbanner dl.enableFormTabbing dd {
  background-color: rgba(255, 255, 255, 0.85);
  border: 1px solid #ddd;
  padding: 1em 0;
  text-align: center;
}

.listingsearchbanner dd p {
  font-size: 80%;
}

.listingsearchbanner ul.formTabs li.firstFormTab a {
  border-top-left-radius: 5px;
}

.listingsearchbanner ul.formTabs li.lastFormTab a {
  border-top-right-radius: 5px;
  border-right: none;
}

.listingsearchbanner ul.formTabs li a {
  background-color: #ddd;
  border-right: 1px solid #fff;
  display: inline-block;
  padding: 0.5em 1em;
}

.listingsearchbanner ul.formTabs li a.selected,
.listingsearchbanner ul.formTabs li a:hover {
  background-color: #205c90;
  color: #fff;
}

.listingsearchbanner form {
  overflow: hidden;
  padding: 0 1em;
}

.listingsearchbanner form div.field {
  margin: 1em 0.25em;
}

.listingsearchbanner form div.field,
.listingsearchbanner form div.formControls {
  display: inline-block;
}

.listingsearchbanner .field input,
.listingsearchbanner .field select,
.listingsearchbanner .formControls input {
  font-size: 1em;
  width: auto;
}

.listingsearchbanner #form-section_1-widgets-q,
.listingsearchbanner #form-section_2-widgets-q,
.listingsearchbanner #form-section_3-widgets-q,
.listingsearchbanner #form-section_4-widgets-q {
  width: 20em;
}

.listingsearchbanner #form-section_1-widgets-price_min,
.listingsearchbanner #form-section_1-widgets-price_max,
.listingsearchbanner #form-section_2-widgets-price_min,
.listingsearchbanner #form-section_2-widgets-price_max,
.listingsearchbanner #form-section_3-widgets-price_min,
.listingsearchbanner #form-section_3-widgets-price_max,
.listingsearchbanner #form-section_4-widgets-price_min,
.listingsearchbanner #form-section_4-widgets-price_max {
  width: 7em;
}

.listingsearchbanner input[type=submit] {
  background-color: #205c90;
  border: none;
  border-radius: 5px;
  color: #fff;
  cursor:pointer;
  padding: 5px 15px;
}
