/* Content Type Icons */
body#visual-portal-wrapper.pat-plone #edit-zone .contenttype-plone-mls-listing-listing:after,
body#visual-portal-wrapper.pat-plone .outer-wrapper .contenttype-plone-mls-listing-listing:before {
  content: '\e825';
}

body#visual-portal-wrapper.pat-plone #edit-zone .contenttype-ps-plone-mls-featured:after,
body#visual-portal-wrapper.pat-plone .outer-wrapper .contenttype-ps-plone-mls-featured:before {
  content: '\e825';
}


/* Action Icons */
.icon-local-mls-config:before {
  content: '\e812';
}

.icon-local-mls-agency-info:before {
  content: '\e812';
}

.icon-listing-collection-config:before {
  content: '\e812';
}

.icon-listing-search-config:before {
  content: '\e812';
}

.icon-recent-listings-config:before {
  content: '\e812';
}

.icon-featured-listings-config:before {
  content: '\e812';
}

.icon-development-collection-config:before {
  content: '\e812';
}


/* Controlpanel Icons */
.icon-controlpanel-propertyshelf_agency_contact_info:before {
    content: '\e816';
}

.icon-controlpanel-propertyshelf_mls:before {
    content: '\e841';
}

.icon-controlpanel-propertyshelf_ui_settings:before {
    content: '\e821';
}


/* Agent Information portlet. */
.portletAgentInformation .agent_avatar img,
.portletAgentInformation .agency_logo img {
  display: block;
  max-width: 100%;
  height: auto;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

.portletAgentInformation .agent_avatar figcaption,
.portletAgentInformation .agency_logo figcaption {
  font-size: 12px;
  background: #fcfcfd;
  margin: 0;
  padding: 6px 12px;
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
}

.portletAgentInformation .contact_details dd {
  margin-bottom: 0.5em;
}

.portletAgentInformation .portletContent .agent_name {
  padding-bottom: 0;
}

.portletAgentInformation .portletContent .agent_title_name {
  padding-top: 0;
}


/* Listing Quick Search portlet. */
.portletQuickSearch select[multiple],
.portletQuickSearch select[size] {
  min-width: 0;
}

.portletQuickSearch .listing__form form span.option {
  display: block;
  margin-right: 0;
}


.portletQuickSearch span.option {
  padding-left: 20px;
}

.portletQuickSearch input.checkbox-widget,
.portletQuickSearch input.radio-widget {
  position: absolute;
  margin-left: -20px;
}


/* Listing Results List */

/* Very small screen. */
@media (max-width: 575px) {
  .listing__results dl dt,
  .listing__results dl dd {
    line-height: 2em;
    display: inline;
  }
  .listing__results dl dd {
    border-bottom: none;
    font-weight: normal;
  }
  .listing__results dl dd:after {
    content: " ";
    display: block;
    border-bottom: 1px solid rgba(0, 0, 0, 0.04);
  }
}

@media (min-width: 576px) {
  .listing__results dl dt {
    float: left;
  }

  .listing__results dl dd {
    border-bottom: 1px solid rgba(0, 0, 0, 0.04);
    text-align: right;
  }
}

.listing__results figure {
  margin-bottom: 20px;
}

.listing__results figure img {
  max-width: 100%;
  width: 100%;
  transition: all .5s linear;
}

.listing__results figure a {
  overflow: hidden;
  display: block;
}

.listing__results figcaption {
  display: none;
}

.listing__results dl dt:after {
  content: ":";
}

.listing__results .listing__object_type {
  clear: both;
}

.listing__results .listing__description {
  clear: both;
}


.listing__results .listing__beds,
.listing__results .listing__baths {
  display: none;
}

/* barceloneta CSS column fixes. */
@media (min-width: 768px) {
  #main-container > .col-sm-6 .listing__results .tileItem dl .col-sm-6 {
    width: 100%
  }
}

@media (min-width: 992px) {
  #main-container > .col-sm-6 .listing__results .tileItem figure.col-md-3,
  #main-container > .col-sm-6 .listing__results .tileItem section.col-md-9 {
    width: 100%
  }
}

@media (min-width: 1260px) {
  #main-container > .col-sm-6 .listing__results .tileItem figure.col-md-3 {
    width: 33.33333333%;
  }

  #main-container > .col-sm-6 .listing__results .tileItem section.col-md-9 {
    width: 66.66666667%;
  }
}
/* End: barceloneta CSS column fixes. */


/* Listing Details */
.listing__detail .autotoc-section > header {
  display: none;
}

.listing__detail dl dt,
.listing__detail dl dd {
  line-height: 2em;
}

.listing__detail dl dt:after {
  content: ":";
}

.listing__detail dl dt {
  float: left;
}

.listing__detail dl dd {
  border-bottom: 1px solid rgba(0, 0, 0, 0.04);
  text-align: right;
}

.listing__detail .listing__beds,
.listing__detail .listing__baths {
  display: none;
}

.listing__detail .listing__summary,
.listing__detail .listing__images,
.listing__detail .listing__longdescription,
.listing__detail .listing__calendar,
.listing__detail .listing__map,
.listing__detail .listing__video {
  margin-bottom: 20px;
}

.listing__detail .map__canvas {
  height: 340px;
  width: 100%;
}


/* Listing Search Form */
.listing__form .autotoc-section >  div > label {
  display: none;
}

.listing__form form span.option {
  display: inline-block;
  margin-right: 2ex;
  vertical-align: middle;
}

.listing__form form span.option input,
.listing__form form span.option label {
  cursor: pointer;
}

.listing__form form span.option label {
  display: inline;
}

.listing__form form .autotabs .option {
  width: 30%;
}

.listing__form form .autotabs .option label {
  max-width: 90%;
}

.listing__form form .autotabs .option input {
  vertical-align: top;
}

.listing__form input.radio-widget + span {
  margin-left: 1ex;
  margin-right: 2ex;
}

.listing__form form span.option input.checkbox-widget + label {
  display: inline-block;
}

.listing__form .listing__form-wrapper {
  background-color: #fff;
  border-radius: 4px 4px 0 0;
  border: 1px solid #edecec;
}

.listing__form .listing__form-wrapper form {
  margin-bottom: 1em;
  margin-top: 1em;
}

.listing__form .listing__form-toggle {
  text-align: center;
}

.listing__form .listing__form-toggle a {
  display: inline-block;
  border-bottom-right-radius: 1em;
  border-bottom-left-radius: 1em;
  padding: 0.5em;
  background-color: #edecec;
  border: 1px solid #e5e5e5;
  border-top: 0;
  font-weight: normal;
}

.listing__form .listing__form-toggle a:focus,
.listing__form .listing__form-toggle a:hover {
  background-color: #fcfcfd;
}

.listing__form .pat-select2 {
  width: 100%;
}

.listing__form select {
  width: 100%;
}

.listing__form .value {
  width: 100%;
}

.listing__form .value select {
  width: 100%;
}

.listing__form .separator {
  display: block;
  text-align: center;
}

@media (min-width: 888px) {
  .listing__form .separator {
    display: none;
  }

  .listing__form .value {
    width: 48%;
  }

  .listing__form .value-min {
    float: left;
  }

  .listing__form .value-max {
    float: right;
  }

  .listing__form .row .field:after {
    content: "";
    display: table;
    clear: both;
  }
}


/* Development Results List */
/* Very small screen. */
@media (max-width: 575px) {
  .development__results dl dt,
  .development__results dl dd {
    line-height: 2em;
    display: inline;
  }
  .development__results dl dd {
    border-bottom: none;
    font-weight: normal;
  }
  .development__results dl dd:after {
    content: " ";
    display: block;
    border-bottom: 1px solid rgba(0, 0, 0, 0.04);
  }
}

@media (min-width: 576px) {
  .development__results dl dt {
    float: left;
  }

  .development__results dl dd {
    border-bottom: 1px solid rgba(0, 0, 0, 0.04);
    text-align: right;
  }
}

.development__results figure {
  margin-bottom: 20px;
}

.development__results figure img {
  max-width: 100%;
  width: 100%;
  transition: all .5s linear;
}

.development__results figure a {
  overflow: hidden;
  display: block;
}

.development__results figcaption {
  display: none;
}

.development__results dl dt:after {
  content: ":";
}

.development__results .development__description {
  clear: both;
}

.development__details .development__banner {
  max-width: 100%;
  width: 100%;
  margin-bottom: 20px;
}

.development__details .lead_image {
  width: 100%;
}

.development__details .lead_image img,
.development__details .area__picture img,
.development__details .representative__avatar img {
  max-width: 100%;
  width: 100%;
}

@media(min-width: 992px) {
  .development__details .lead_image {
    max-width: 35%;
  }
}

.development__details .autotoc-section > header {
  display: none;
}

.development__details .map__canvas {
  height: 340px;
  width: 100%;
  margin-bottom: 1em;
}

.development__amenities {
  text-align: center;
}
.development__amenities span {
  font-size: 4em;
}

@media(max-width: 767px) {
  .development__details .distanceicon {
    margin-top: 1em;
    text-align: center;
  }

  .development__details .distanceicon span.icon {
    line-height: 1em;
  }
}

.development__details .distanceicon span.icon {
  font-size: 4em;
  margin-top: 0;
}

@media(min-width: 768px) {
  .development__details .distanceicon span.icon {
    font-size: 3em;
    margin-top: 0.2em;
  }
}

@media(min-width: 1052px) {
  .development__details .distanceicon span.icon {
    font-size: 3.5em;
    margin-top: 0.125em;
  }
}

.development__details .representatives__item {
  margin-bottom: 2em;
}

.development__details .development__anchorlink {
  position: fixed;
  right: 0;
  top: 40%;
  transform: rotate(90deg);
  transform-origin: right top 0;
  z-index: 99;
}


.listingsearchbanner {
  background-position: 50% 50%;
  background-size: cover;
  margin-top: -20px;
  padding: 8em 0;
}

.listingsearchbanner .autotoc-section header {
  display: none;
}

.listingsearchbanner input[type=submit] {
  background-color: #205c90;
  border: none;
  border-radius: 5px;
  color: #fff;
  cursor:pointer;
  padding: 5px 15px;
}

.listingsearchbanner form .formControls,
.listingsearchbanner .pat-autotoc.autotabs .formControls,
.listingsearchbanner .autotabs .formControls {
  background: none;
  border: none;
  box-shadow: none;
  padding: 0;
  margin: 0;
}

@media (min-width: 768px) {
  .listingsearchbanner form .field,
  .listingsearchbanner form .formControls {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
    padding: 0.5em 0;
  }

  .listingsearchbanner section {
    text-align: center;
  }

  .listingsearchbanner #form-section_1-widgets-q,
  .listingsearchbanner #form-section_2-widgets-q,
  .listingsearchbanner #form-section_3-widgets-q,
  .listingsearchbanner #form-section_4-widgets-q {
    width: 20em;
  }

  .listingsearchbanner #form-section_1-widgets-price_min,
  .listingsearchbanner #form-section_1-widgets-price_max,
  .listingsearchbanner #form-section_2-widgets-price_min,
  .listingsearchbanner #form-section_2-widgets-price_max,
  .listingsearchbanner #form-section_3-widgets-price_min,
  .listingsearchbanner #form-section_3-widgets-price_max,
  .listingsearchbanner #form-section_4-widgets-price_min,
  .listingsearchbanner #form-section_4-widgets-price_max {
    width: 7em;
  }

  .listingsearchbanner #form-section_1-widgets-beds,
  .listingsearchbanner #form-section_2-widgets-beds,
  .listingsearchbanner #form-section_3-widgets-beds,
  .listingsearchbanner #form-section_4-widgets-beds {
    min-width: auto;
  }
}


.embed-responsive {
  position: relative;
  display: block;
  height: 0;
  padding: 0;
  overflow: hidden;
}

.embed-responsive-16by9 {
  padding-bottom: 56.25%;
}

.embed-responsive .embed-responsive-item, .embed-responsive embed, .embed-responsive iframe, .embed-responsive object, .embed-responsive video {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border: 0;
}
